<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Phone.UI.Input

Windows Runtime (WinRT) APIs for for the `Windows.Phone.UI.Input` namespace.

This package provides the `winrt.windows.phone.ui.input` module.
